"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRepository = exports.RESET_PASSWORD_TEMPLATE = void 0;
const http_status_codes_1 = require("http-status-codes");
const User_1 = require("../Models/User");
const Report_1 = require("../Models/Report");
const Rating_1 = require("../Models/Rating");
const MenteeRequest_1 = require("../Models/MenteeRequest");
const Comment_1 = require("../Models/Comment");
const Image_1 = require("../Models/Image");
const Language_1 = require("../Models/Language");
const Category_1 = require("../Models/Category");
const HttpResponse_1 = require("../Helpers/HttpResponse");
const bcrypt_1 = __importDefault(require("bcrypt"));
const Constants_1 = require("../Helpers/Constants");
const Utility_1 = require("../Helpers/Utility");
const Constants_2 = require("../Helpers/Constants");
const crypto = require('crypto');
const sgMail = require('@sendgrid/mail');
const jade = require('pug');
const mailer = require("nodemailer");
const sharp = require('sharp');
const General_1 = require("../Helpers/General");
const mongoose = require('mongoose');
exports.RESET_PASSWORD_TEMPLATE = 'src/Views/mail-templates/forgot-password-link.pug';
class UserRepository {
    constructor() { }
    getUsers() {
        return __awaiter(this, void 0, void 0, function* () {
            return User_1.User.find({}).select({ name: 1, email: 1 });
        });
    }
    createUser(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const saltRounds = 10; //TODO: make constant
                const { email, isSocial } = req.body;
                /*Check User exist or not*/
                const userExist = yield User_1.User.findOne({ email }).lean();
                if (userExist) {
                    if (isSocial) {
                        const { socialLoginType, socialId } = req.body;
                        const obj = {};
                        Object.assign(obj, { socialLoginType });
                        if (socialLoginType === 'google') {
                            Object.assign(obj, { socialId: socialId });
                        }
                        else {
                            Object.assign(obj, { socialIdApple: socialId });
                        }
                        const user = yield User_1.User.findByIdAndUpdate({ _id: userExist._id }, {
                            $set: obj,
                        }, { returnOriginal: false });
                        return HttpResponse_1.HttpResponse.success(user);
                    }
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.OK, {}, Constants_1.RESPONSE_MESSAGES.USER_EXIST);
                }
                /*Social Login & SignUp*/
                if (isSocial) {
                    const { socialLoginType } = req.body;
                    const socialExist = yield User_1.User.findOne({ email, socialLoginType }).lean();
                    if (!socialExist) {
                        return this.socialLoginUser(req);
                    }
                    return HttpResponse_1.HttpResponse.success(socialExist);
                }
                /*Password Encryption*/
                const password = !isSocial
                    ? bcrypt_1.default.hashSync(req.body.password, saltRounds)
                    : "";
                /*Signup User*/
                const user = yield this.signupUser(req, password);
                /*Generate JWT Token*/
                const accessToken = yield (0, Utility_1.generateAccessToken)(user, process.env.ACCESS_TOKEN_SECRET || "");
                const result = {
                    user,
                    accessToken,
                };
                return HttpResponse_1.HttpResponse.success(result);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    updateUser(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const saltRounds = 10; //TODO: make constant
                const { id } = req.body;
                /*Check User exist or not*/
                const userExist = yield User_1.User.findOne({ _id: id }).lean();
                if (!userExist) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
                }
                /*Password Encryption*/
                let password = '';
                if (req.body.hasOwnProperty('password')) {
                    password = bcrypt_1.default.hashSync(req.body.password, saltRounds);
                    Object.assign(req.body, { password: password });
                }
                /*Update User profile*/
                const user = yield this.updateProfile(req);
                /*Generate JWT Token*/
                const accessToken = yield (0, Utility_1.generateAccessToken)(user, process.env.ACCESS_TOKEN_SECRET || "");
                const result = {
                    user,
                    accessToken,
                };
                return HttpResponse_1.HttpResponse.success(result);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    signupUser(req, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const { name, email, phone, gender, speak, nationality, type, isSocial, socialId, socialLoginType, education, instagramId, story, company, occupation, continentId, continentName, countryId, countryName, cityId, cityName, dreamContinentId, dreamContinentName, dreamCountryId, dreamCountryName, dreamCityId, dreamCityName, } = req.body;
            const user = new User_1.User({
                name,
                email,
                phone,
                password,
                gender,
                speak,
                nationality,
                type,
                isSocial,
                socialLoginType,
                socialId,
                isDeleted: false,
                isMentor: false,
                education,
                instagramId,
                story,
                company,
                occupation,
                continentId,
                continentName,
                countryId,
                countryName,
                cityId,
                cityName,
                dreamContinentId,
                dreamContinentName,
                dreamCountryId,
                dreamCountryName,
                dreamCityId,
                dreamCityName,
            });
            yield user.save();
            return user;
        });
    }
    getUserProfile(req) {
        return __awaiter(this, void 0, void 0, function* () {
            const { id } = req.body;
            const user = yield User_1.User.find({ _id: id }).populate({
                path: 'speak',
                model: Language_1.Language,
            });
            if (!user) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
            }
            return HttpResponse_1.HttpResponse.success(user);
        });
    }
    updateProfile(req) {
        return __awaiter(this, void 0, void 0, function* () {
            const obj = req.body;
            const { name, speak, nationality, gender, instagramId, linkedinId, education, degree, company, occupation, story, zipcode, type, password, isProfileCompleted, status, service, serviceRate, phone, continentId, continentName, countryId, countryName, cityId, cityName, dreamContinentId, dreamContinentName, dreamCountryId, dreamCountryName, dreamCityId, dreamCityName, } = obj;
            const user = yield User_1.User.findByIdAndUpdate({ _id: obj.id }, {
                $set: {
                    name,
                    speak,
                    nationality,
                    gender,
                    instagramId,
                    linkedinId,
                    education,
                    degree,
                    company,
                    occupation,
                    story,
                    zipcode,
                    type,
                    isMentor: type === 'both',
                    password,
                    isProfileCompleted,
                    status,
                    service,
                    serviceRate,
                    continentId,
                    continentName,
                    countryId,
                    countryName,
                    cityId,
                    cityName,
                    dreamContinentId,
                    dreamContinentName,
                    dreamCountryId,
                    dreamCountryName,
                    dreamCityId,
                    dreamCityName,
                    phone,
                },
            }, { returnOriginal: false });
            return user;
        });
    }
    uploadProfilePicture(req) {
        return __awaiter(this, void 0, void 0, function* () {
            const imageName = req['files'];
            if (imageName[0].mimetype !== 'image/jpeg' && imageName[0].mimetype !== 'image/png') {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, {}, Constants_1.RESPONSE_MESSAGES.INVALID_EXTENSION);
            }
            const imageFile = imageName[0].filename;
            const imagePath = imageName[0].path;
            try {
                yield this.createImageThumbnail(imageFile);
                const user = yield User_1.User.findOne({ _id: req.body.userId, isDeleted: false }).lean();
                if (user === null) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.UNAUTHORIZED, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
                }
                const imgObj = {
                    profile: '',
                    cover: '',
                };
                if (req.body.type === 'profile') {
                    imgObj.profile = `${Constants_2.IMAGE_PATH}${imageFile}`;
                }
                else {
                    imgObj.cover = `${Constants_2.IMAGE_PATH}${imageFile}`;
                }
                yield User_1.User.findByIdAndUpdate({ _id: req.body.userId }, {
                    $set: {
                        images: imgObj
                    },
                }, { returnOriginal: false });
                const img = yield Image_1.Image.findOne({ userId: mongoose.Types.ObjectId(req.body.userId) }).lean();
                let data = '';
                if (img) {
                    data = yield Image_1.Image.findByIdAndUpdate({ _id: img._id }, {
                        $set: {
                            type: req.body.type,
                            userId: req.body.userId,
                            image: imageFile,
                            path: imagePath,
                        },
                    }, { returnOriginal: false });
                }
                else {
                    const imageObj = new Image_1.Image({
                        type: req.body.type,
                        userId: req.body.userId,
                        image: imageFile,
                        path: imagePath,
                    });
                    data = yield imageObj.save();
                }
                return HttpResponse_1.HttpResponse.success(data);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    createImageThumbnail(file, type) {
        return new Promise((resolve) => {
            const fn = () => __awaiter(this, void 0, void 0, function* () {
                try {
                    const fileName = file.split('.')[0];
                    yield sharp(`${Constants_1.IMAGE_CONSTANTS.dirImage}${file}`)
                        .resize(50, 50)
                        .withMetadata()
                        .toFile(`${Constants_1.IMAGE_CONSTANTS.dirImage}${fileName}-thumbnail.png`);
                }
                catch (err) {
                    console.error('error on creating thumbnail', err);
                }
            });
            fn().then();
            resolve(true);
        });
    }
    ;
    loginUser(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { email, password, isSocial } = req.body;
                /*Social Login & SignUp */
                if (isSocial) {
                    return this.socialLoginUser(req, true);
                }
                const user = yield User_1.User.findOne({ email, isDeleted: false }).lean();
                if (user === null) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
                }
                else {
                    /*Password Encryption*/
                    const match = yield bcrypt_1.default.compare(password, user.password);
                    if (!match) {
                        return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.UNAUTHORIZED, [Constants_1.RESPONSE_MESSAGES.WRONG_PASSWORD], '');
                    }
                    /*Generate JWT Token*/
                    const accessToken = yield (0, Utility_1.generateAccessToken)(user, process.env.ACCESS_TOKEN_SECRET || "");
                    const result = {
                        user,
                        accessToken,
                    };
                    return HttpResponse_1.HttpResponse.success(result);
                }
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    deleteUser(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { id } = req.body;
                const user = yield User_1.User.findOne({ _id: id });
                if (!user) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
                }
                yield User_1.User.findByIdAndUpdate(id, {
                    $set: {
                        isDeleted: true,
                    },
                });
                return HttpResponse_1.HttpResponse.success({});
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    emailVerification(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { email } = req.body;
                const user = yield User_1.User.findOne({ email: email });
                if (user) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, [Constants_1.RESPONSE_MESSAGES.EMAIL_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success({});
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    phoneVerification(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { phone } = req.body;
                const user = yield User_1.User.findOne({ phone: phone });
                if (user) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, [Constants_1.RESPONSE_MESSAGES.PHONE_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success({});
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    socialLoginUser(req, isLogin = false) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { socialLoginType, socialId, isSocial } = req.body;
                let user;
                const userExist = yield User_1.User.findOne({
                    isSocial,
                    socialLoginType,
                    socialId,
                }).lean();
                if (!userExist) {
                    /*SignUp User*/
                    if (!isLogin) {
                        user = yield this.signupUser(req, "");
                    }
                    else {
                        return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.UNAUTHORIZED, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
                    }
                }
                else {
                    user = userExist;
                }
                /*Generate JWT Token*/
                const accessToken = yield (0, Utility_1.generateAccessToken)(user, process.env.ACCESS_TOKEN_SECRET || "");
                const result = {
                    user,
                    accessToken,
                };
                return HttpResponse_1.HttpResponse.success(result);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    allMentors() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const mentors = yield User_1.User.find({ type: "both", isDeleted: false }).find();
                if (mentors.length === 0) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.NO_MENTOR_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(mentors);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    getMentorFilters() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const languages = yield Language_1.Language.find({});
                const categories = yield Category_1.Category.find({});
                const data = {
                    Speaks: languages,
                    Service_Types: categories
                };
                return HttpResponse_1.HttpResponse.success(data);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    filterMentors(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { city, id, parent_id, sub_parent_id, language } = req.body;
                let obj = { city: city, type: "both" };
                if (language)
                    Object.assign(obj, { speak: { $all: language } });
                const mentors = yield User_1.User.find(obj).find();
                let filterList = '';
                if (id !== undefined || parent_id !== undefined || sub_parent_id !== undefined) {
                    filterList = (0, General_1.filterMentor)(mentors, id, parent_id, sub_parent_id);
                    if (filterList.length === 0) {
                        return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.NO_MENTOR_EXIST], '');
                    }
                    return HttpResponse_1.HttpResponse.success(filterList);
                }
                if (mentors.length === 0) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.NO_MENTOR_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(mentors);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    mentorList(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { menteeId } = req.body;
                const mentors = yield MenteeRequest_1.MenteeRequest.find({ requestBy: mongoose.Types.ObjectId(menteeId), status: "Approved" })
                    .populate({
                    path: 'requestBy',
                    model: User_1.User,
                })
                    .populate({
                    path: 'requestTo',
                    model: User_1.User,
                });
                if (mentors.length === 0) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.NO_MENTOR_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(mentors);
            }
            catch (err) {
                console.log(err);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    menteeList(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { mentorId } = req.body;
                const mentors = yield MenteeRequest_1.MenteeRequest.find({ requestTo: mongoose.Types.ObjectId(mentorId), status: "Approved" })
                    .populate({
                    path: 'requestBy',
                    model: User_1.User,
                })
                    .populate({
                    path: 'requestTo',
                    model: User_1.User,
                });
                if (mentors.length === 0) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.NO_MENTEE_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(mentors);
            }
            catch (err) {
                console.log(err);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    searchMentor(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { cityId } = req.body;
                const obj = { isMentor: true };
                if (cityId)
                    Object.assign(obj, { cityId: cityId });
                const mentors = yield User_1.User.find(obj);
                if (mentors.length === 0) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.NO_MENTOR_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(mentors);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    rateMentor(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { rateBy, rateTo, rate, comment } = req.body;
                const rating = new Rating_1.Rating({
                    rateBy,
                    rateTo,
                    rate,
                    comment,
                });
                yield rating.save();
                return HttpResponse_1.HttpResponse.success(rating);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    reportMentor(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { reportBy, reportTo, reason } = req.body;
                const report = new Report_1.Report({
                    reportBy,
                    reportTo,
                    reason,
                });
                yield report.save();
                return HttpResponse_1.HttpResponse.success(report);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    menteeRequest(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { requestBy, requestTo, status } = req.body;
                const isRequest = yield MenteeRequest_1.MenteeRequest.findOne({ requestBy: mongoose.Types.ObjectId(requestBy), requestTo: mongoose.Types.ObjectId(requestTo) });
                let request = '';
                if (isRequest) {
                    request = yield MenteeRequest_1.MenteeRequest.findByIdAndUpdate({ _id: isRequest._id }, {
                        $set: {
                            requestBy,
                            requestTo,
                            status,
                        },
                    }, { returnOriginal: false });
                }
                else {
                    request = new MenteeRequest_1.MenteeRequest({
                        requestBy,
                        requestTo,
                        status,
                    });
                    yield request.save();
                }
                return HttpResponse_1.HttpResponse.success(request);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    menteeRequestListing(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { mentorId } = req.body;
                const requests = yield MenteeRequest_1.MenteeRequest.find({ requestTo: mentorId, status: 'Pending' })
                    .populate({ path: 'requestBy', model: User_1.User })
                    .populate({ path: 'requestTo', model: User_1.User });
                if (!requests) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.REQUEST_NOT_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(requests);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    menteeRequestApproveReject(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { requestId, status } = req.body;
                yield MenteeRequest_1.MenteeRequest.findByIdAndUpdate({ _id: requestId }, {
                    $set: {
                        status
                    }
                });
                const request = yield MenteeRequest_1.MenteeRequest.find({ _id: requestId });
                return HttpResponse_1.HttpResponse.success(request);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    exploreMentor(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { countryId } = req.body;
                const user = yield User_1.User.find({ countryId: countryId });
                return HttpResponse_1.HttpResponse.success(user);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    commentsList(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { mentorId } = req.body;
                const comment = yield Comment_1.Comment.find({ commentTo: mentorId });
                // .populate({ path: 'commentBy', modal: User });
                // .populate({ path: 'commentTo', modal: User });
                if (!comment) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.COMMENT_NOT_EXIST], '');
                }
                return HttpResponse_1.HttpResponse.success(comment);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    comments(req) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { commentBy, commentTo, comment } = req.body;
                const comments = new Comment_1.Comment({
                    commentBy,
                    commentTo,
                    comment,
                });
                yield comments.save();
                return HttpResponse_1.HttpResponse.success(comments);
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    forgotPassword(req) {
        return __awaiter(this, void 0, void 0, function* () {
            const { email } = req.body;
            try {
                const user = yield User_1.User.findOne({ email, isDeleted: false });
                if (!user) {
                    return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.NOT_FOUND, [Constants_1.RESPONSE_MESSAGES.USER_NOT_EXIST], '');
                }
                let resetToken = crypto.randomBytes(32).toString('hex');
                const hash = yield crypto.createHash('sha256').update(resetToken).digest('hex');
                yield this.sendEmail(user.email, '', 'Reset Password', exports.RESET_PASSWORD_TEMPLATE, `reset_password/${hash}/${user._id}`);
                return HttpResponse_1.HttpResponse.success({ message: 'A link has been sent to your email' });
            }
            catch (err) {
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.StatusCodes.BAD_REQUEST, err);
            }
        });
    }
    ;
    sendEmail(email, template, subject, htmlTemplate, token) {
        return __awaiter(this, void 0, void 0, function* () {
            // if (!email) return '';
            // sgMail.setApiKey('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');
            // const msg = {
            //   to: email,
            //   from: 'noreply@movementor.com',
            //   subject: subject,
            //   text: 'Movementor',
            //   html: jade.renderFile(htmlTemplate, { template: template, token: token }),
            // };
            // try {
            //   await sgMail.send(msg);
            //   return '';
            // } catch (error) {
            //   return error;
            // }
            // Generate test SMTP service account from ethereal.email
            // Only needed if you don't have a real mail account for testing
            let testAccount = yield mailer.createTestAccount();
            // create reusable transporter object using the default SMTP transport
            let transporter = mailer.createTransport({
                host: "smtp.ethereal.email",
                port: 587,
                secure: false,
                auth: {
                    user: testAccount.user,
                    pass: testAccount.pass, // generated ethereal password
                },
            });
            // send mail with defined transport object
            let info = yield transporter.sendMail({
                from: 'noreply@movementor.com',
                to: email,
                subject: subject,
                text: 'Movementor',
                html: jade.renderFile(htmlTemplate, { template: template, token: token }),
                // html: "<b>Hello world?</b>", // html body
            });
            console.log("Message sent: %s", info.messageId);
            // Message sent: <b658f8ca-6296-ccf4-8306-87d57a0b4321@example.com>
            // Preview only available when sending through an Ethereal account
            console.log("Preview URL: %s", mailer.getTestMessageUrl(info));
            // Preview URL: https://ethereal.email/message/WaQKMgKddxQDoou...
        });
    }
}
const userRepository = new UserRepository();
exports.UserRepository = userRepository;
