"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserService = void 0;
const UserRepository_1 = require("../Repositories/UserRepository");
const http_status_codes_1 = __importDefault(require("http-status-codes"));
const HttpResponse_1 = require("../Helpers/HttpResponse");
const Constants_1 = require("../Helpers/Constants");
const joi_1 = __importDefault(require("joi"));
/*Validation Schema*/
const profileSchema = joi_1.default.object({
    id: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.USER_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.USER_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.USER_ID_NOT_EMPTY}`,
    }),
});
const mentorListSchema = joi_1.default.object({
    menteeId: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
    }),
});
const menteeListSchema = joi_1.default.object({
    mentorId: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
});
const allMentorSchema = joi_1.default.object({
    city: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.CITY_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.CITY_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.CITY_NOT_EMPTY}`,
    }),
});
const rateMentorSchema = joi_1.default.object({
    rateBy: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
    }),
    rateTo: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
    rate: joi_1.default.number().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.RATING_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.RATING_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.RATING_NOT_EMPTY}`,
    }),
    comment: joi_1.default.string(),
});
const reportMentorSchema = joi_1.default.object({
    reportBy: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
    }),
    reportTo: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
    reason: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.REASON_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.REASON_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.REASON_NOT_EMPTY}`,
    }),
});
const menteeRequestSchema = joi_1.default.object({
    requestBy: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
    }),
    requestTo: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
    status: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.STATUS_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.STATUS_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.STATUS_NOT_EMPTY}`,
    }),
});
const menteeRequestListingSchema = joi_1.default.object({
    mentorId: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
});
const requestApproveRejectSchema = joi_1.default.object({
    requestId: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.REQUEST_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.REQUEST_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.REQUEST_NOT_EMPTY}`,
    }),
    status: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.STATUS_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.STATUS_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.STATUS_NOT_EMPTY}`,
    }),
});
const commentsListSchema = joi_1.default.object({
    mentorId: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
});
const commentsSchema = joi_1.default.object({
    commentBy: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTEE_ID_REQUIRED}`,
    }),
    commentTo: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.MENTOR_ID_NOT_EMPTY}`,
    }),
    comment: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.COMMENT_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.COMMENT_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.COMMENT_NOT_EMPTY}`,
    }),
});
const exploreMentorSchema = joi_1.default.object({
    countryId: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.COUNTRY_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.COUNTRY_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.COUNTRY_NOT_EMPTY}`,
    }),
});
/*End Validation Schema*/
class UserService {
    constructor() { }
    getUserProfile(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield profileSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.getUserProfile(req);
        });
    }
    updateUser(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield UserRepository_1.UserRepository.updateUser(req);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
        });
    }
    uploadProfilePicture(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield UserRepository_1.UserRepository.uploadProfilePicture(req);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
        });
    }
    getMentorFilters() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield UserRepository_1.UserRepository.getMentorFilters();
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
        });
    }
    filterMentors(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield UserRepository_1.UserRepository.filterMentors(req);
                // await allMentorSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            // return await UserRepository.filterMentors(req);
        });
    }
    getAllMentors() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield UserRepository_1.UserRepository.allMentors();
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
        });
    }
    getMentorList(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield mentorListSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.mentorList(req);
        });
    }
    getMenteeList(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield menteeListSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.menteeList(req);
        });
    }
    searchMentor(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield UserRepository_1.UserRepository.searchMentor(req);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
        });
    }
    rateMentor(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield rateMentorSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.rateMentor(req);
        });
    }
    reportMentor(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield reportMentorSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.reportMentor(req);
        });
    }
    menteeRequest(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield menteeRequestSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.menteeRequest(req);
        });
    }
    menteeRequestListing(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield menteeRequestListingSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors.data);
            }
            return yield UserRepository_1.UserRepository.menteeRequestListing(req);
        });
    }
    menteeRequestApproveReject(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield requestApproveRejectSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors.data);
            }
            return yield UserRepository_1.UserRepository.menteeRequestApproveReject(req);
        });
    }
    exploreMentor(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield exploreMentorSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors.data);
            }
            return yield UserRepository_1.UserRepository.exploreMentor(req);
        });
    }
    commentsList(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield commentsListSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors.data);
            }
            return yield UserRepository_1.UserRepository.commentsList(req);
        });
    }
    comments(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield commentsSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors.data);
            }
            return yield UserRepository_1.UserRepository.comments(req);
        });
    }
}
const userService = new UserService();
exports.UserService = userService;
